@@ -505,7 +505,7 @@ class Base_Page(Borg, unittest.TestCase):
             self.driver.switch_to.frame(self.driver.find_elements_by_tag_name("iframe")[index])
         elif frame_id is not None:  # add by myself
             self.driver.switch_to.frame(frame_id)
-        # else:     # There are cases which direct switch to default content only
+        # else:
         #     raise Exception("All arguments are None in switch_1st_layer_frame()")
 
     def switch_under_frame(self, name=None, index=None, frame_id=None, element=None, wait_time=0.5):
@@ -1008,6 +1008,17 @@ class Base_Page(Borg, unittest.TestCase):
             result_flag = True
         return result_flag
 
+    def check_dom_element_is_display_on_screen_by_yaxis_and_js(self, element):
+        """Assume window inner height is larger than element height"""
+        y = element.location.get("y")
+        height = element.size.get("height")
+        top = self.execute_javascript_with_return("window.pageYOffset")
+        window_height = self.execute_javascript_with_return("window.innerHeight")
+        if top < y < (top + window_height - height):
+            return True
+        else:
+            return False
+
     def elementIsDisplayed(self, element):
         """element should be a Selenium Select object"""
         result_flag = True
@@ -1191,7 +1202,7 @@ class Base_Page(Borg, unittest.TestCase):
         #
         # return self.gif_file_name
         if self.screenshot != 'off':
-            self.gif_file_name = Gif_Maker.make_gif(self.screenshot_dir, name=self.calling_module)
+            self.gif_file_name = Gif_Maker.make_gif(self.screenshot_dir, self.report_path, name=self.report_name)
             return self.gif_file_name
 
     def wait(self, wait_seconds=5.0, locator=None):
@@ -1354,4 +1365,19 @@ class Base_Page(Borg, unittest.TestCase):
             self.exceptions.append("An exception occurred when scroll by amount")
             return None
 
+    def scroll_to_dom_element_by_js(self, element, wait_time=1):
+        """Assume window inner height is larger than element height
+        Do nothing if the element already on screen
+        Will screen down until the element display in the middle of windows
+        Default Wait 1 second after calling js.
+        ***Please be careful next operation will be executed while scrolling"""
+        y = element.location.get("y")
+        top = self.execute_javascript_with_return("window.pageYOffset")
+        window = self.execute_javascript_with_return("window.innerHeight")
+        if self.check_dom_element_is_display_on_screen_by_yaxis_and_js(element):
+            return
+        cmd = "window.scrollBy(0, %s)" % str(y-(top+window)+(window/2))
+        self.execute_javascript(cmd)
+        self.wait(wait_time)
+
     # _get_locator = staticmethod(_get_locator) "COMMENT BECAUSE _get_locator commented"
